--[[
Copyright (c) 2009, LordFarlander
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
]]--

local Broker_RecZone = Broker_RecZone;

if( not Broker_RecZone ) then
    return;
end--if

local Z = LibStub( "LibBabble-Zone-3.0" ):GetLookupTable();
local L = LibStub( "AceLocale-3.0" ):GetLocale( "Broker_RecZone" );

local function zn( zonename, x )
    for nr, zone in ipairs( zones ) do
        if( ( zone.name == zonename ) and ( ( not x ) or ( zone.x and ( zone.x == x ) ) ) ) then
            return nr;
        end--if
    end--for
end--function zn( zonename, x )

Broker_RecZone.vars.zones = {
-- Eastern Kingdoms
    { name = Z["Stormwind City"], low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_CITY, continent = RZ_EASTERN },
    { name = Z["Ironforge"], low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_CITY, continent = RZ_EASTERN },
    { name = Z["Undercity"], low = 0, high = 0, faction = RZ_HORDE, type = RZ_CITY, continent = RZ_EASTERN },
    { name = Z["Dun Morogh"], low = 1, high = 12, faction = RZ_ALLIANCE, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Elwynn Forest"], low = 1, high = 12, faction = RZ_ALLIANCE, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Tirisfal Glades"], low = 1, high = 12, faction = RZ_HORDE, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Loch Modan"], low = 10, high = 20, faction = RZ_ALLIANCE, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Westfall"], low = 10, high = 20, faction = RZ_ALLIANCE, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Silverpine Forest"], low = 10, high = 20, faction = RZ_HORDE, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Redridge Mountains"], low = 15, high = 25, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Wetlands"], low = 20, high = 30, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Duskwood"], low = 20, high = 30, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Hillsbrad Foothills"], low = 20, high = 30, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Alterac Mountains"], low = 30, high = 40, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Arathi Highlands"], low = 30, high = 40, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Stranglethorn Vale"], low = 30, high = 45, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Badlands"], low = 35, high = 45, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Swamp of Sorrows"], low = 35, high = 45, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["The Hinterlands"], low = 40, high = 50, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Searing Gorge"], low = 43, high = 50, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Blasted Lands"], low = 47, high = 55, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Burning Steppes"], low = 50, high = 60, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Western Plaguelands"], low = 50, high = 60, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Deadwind Pass"], low = 55, high = 60, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Eastern Plaguelands"], low = 55, high = 60, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Isle of Quel'Danas"], low = 65, high = 70, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },
-- Blood Elf
    { name = Z["Silvermoon City"], low = 0, high = 0, faction = RZ_HORDE, type = RZ_CITY, continent = RZ_EASTERN },
    { name = Z["Eversong Woods"], low = 1, high = 12, faction = RZ_HORDE, type = RZ_ZONE, continent = RZ_EASTERN },
    { name = Z["Ghostlands"], low = 10, high = 20, faction = RZ_HORDE, type = RZ_ZONE, continent = RZ_EASTERN },

-- Kalimdor
    { name = Z["Darnassus"], low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_CITY, continent = RZ_KALIMDOR },
    { name = Z["Orgrimmar"], low = 0, high = 0, faction = RZ_HORDE, type = RZ_CITY, continent = RZ_KALIMDOR },
    { name = Z["Thunder Bluff"], low = 0, high = 0, faction = RZ_HORDE, type = RZ_CITY, continent = RZ_KALIMDOR },
    { name = Z["Moonglade"], low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_CITY, continent = RZ_KALIMDOR },
    { name = Z["Teldrassil"], low = 1, high = 12, faction = RZ_ALLIANCE, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Durotar"], low = 1, high = 12, faction = RZ_HORDE, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Mulgore"], low = 1, high = 12, faction = RZ_HORDE, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Darkshore"], low = 10, high = 20, faction = RZ_ALLIANCE, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["The Barrens"], low = 10, high = 25, faction = RZ_HORDE, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Stonetalon Mountains"], low = 15, high = 27, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Ashenvale"], low = 15, high = 30, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Thousand Needles"], low = 25, high = 35, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Desolace"], low = 30, high = 40, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Dustwallow Marsh"], low = 35, high = 45, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Feralas"], low = 40, high = 50, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Tanaris"], low = 40, high = 50, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Un'Goro Crater"], low = 48, high = 55, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Azshara"], low = 48, high = 55, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Felwood"], low = 48, high = 55, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Silithus"], low = 55, high = 60, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Winterspring"], low = 55, high = 60, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_KALIMDOR },
-- Draenei
    { name = Z["The Exodar"], low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_CITY, continent = RZ_KALIMDOR },
    { name = Z["Azuremyst Isle"], low = 1, high = 12, faction = RZ_ALLIANCE, type = RZ_ZONE, continent = RZ_KALIMDOR },
    { name = Z["Bloodmyst Isle"], low = 10, high = 20, faction = RZ_ALLIANCE, type = RZ_ZONE, continent = RZ_KALIMDOR },

-- Outland
    { name = Z["Shattrath City"], low = 0, high = 0, faction = RZ_SANCTUARY, type = RZ_CITY, continent = RZ_OUTLAND },
    { name = Z["Hellfire Peninsula"], low = 58, high = 63, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_OUTLAND },
    { name = Z["Zangarmarsh"], low = 60, high = 64, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_OUTLAND },
    { name = Z["Terokkar Forest"], low = 62, high = 65, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_OUTLAND },
    { name = Z["Nagrand"], low = 64, high = 67, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_OUTLAND },
    { name = Z["Blade's Edge Mountains"], low = 65, high = 68, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_OUTLAND },
    { name = Z["Netherstorm"], low = 67, high = 70, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_OUTLAND },
    { name = Z["Shadowmoon Valley"], low = 67, high = 70, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_OUTLAND },

-- Northrend
    { name = Z["Borean Tundra"], low = 68, high = 72, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_NORTHREND },
    { name = Z["Howling Fjord"], low = 68, high = 72, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_NORTHREND },
    { name = Z["Dragonblight"], low = 71, high = 74, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_NORTHREND },
    { name = Z["Grizzly Hills"], low = 73, high = 75, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_NORTHREND },
    { name = Z["Zul'Drak"], low = 74, high = 77, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_NORTHREND },
    { name = Z["Sholazar Basin"], low = 75, high = 78, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_NORTHREND },
    { name = Z["Crystalsong Forest"], low = 77, high = 80, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_NORTHREND },
    { name = Z["The Storm Peaks"], low = 76, high = 80, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_NORTHREND },
    { name = Z["Icecrown"], low = 77, high = 80, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_NORTHREND },
    { name = Z["Wintergrasp"], low = 77, high = 80, faction = RZ_PVP, type = RZ_PVP, continent = RZ_NORTHREND },
    { name = Z["Dalaran"], low = 0, high = 0, faction = RZ_SANCTUARY, type = RZ_CITY, continent = RZ_NORTHREND },

-- Death Knights
    { name = Z["Plaguelands: The Scarlet Enclave"], low = 55, high = 58, faction = RZ_CONTESTED, type = RZ_ZONE, continent = RZ_EASTERN },

-- Classic Dungeons
    { name = Z["Ragefire Chasm"], low = 13, high = 20, type = RZ_INSTANCE, faction = RZ_HORDE, continent = RZ_KALIMDOR },
    { name = Z["Wailing Caverns"], low = 17, high = 24, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_KALIMDOR },
    { name = Z["The Deadmines"], low = 17, high = 26, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_EASTERN },
    { name = Z["The Stockade"], low = 24, high = 32, type = RZ_INSTANCE, faction = RZ_ALLIANCE, continent = RZ_EASTERN },
    { name = Z["Shadowfang Keep"], low = 20, high = 28, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_EASTERN },
    { name = Z["Blackfathom Deeps"], low = 23, high = 30, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_KALIMDOR },
    { name = Z["Gnomeregan"], low = 29, high = 38, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_EASTERN },
    { name = Z["Razorfen Kraul"], low = 29, high = 38, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_KALIMDOR },
    { name = Z["Scarlet Monastery"], low = 33, high = 44, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_EASTERN },
    { name = Z["Razorfen Downs"], low = 37, high = 46, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_KALIMDOR },
    { name = Z["Uldaman"], low = 38, high = 46, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_EASTERN },
    { name = Z["Maraudon"], low = 45, high = 55, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_KALIMDOR },
    { name = Z["Zul'Farrak"], low = 43, high = 50, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_KALIMDOR },
    { name = Z["The Temple of Atal'Hakkar"], low = 44, high = 52, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_EASTERN },
    { name = Z["Blackrock Depths"], low = 50, high = 56, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_EASTERN },
    { name = Z["Blackrock Spire"], low = 56, high = 60, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_EASTERN },
    { name = Z["Stratholme"], low = 56, high = 60, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_EASTERN },
    { name = Z["Dire Maul"], low = 56, high = 60, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_KALIMDOR },
    { name = Z["Scholomance"], low = 58, high = 60, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_EASTERN },
-- Classic Raids
    { name = Z["Blackwing Lair"], low = 60, high = 62, type = RZ_RAID, faction = RZ_CONTESTED, continent = RZ_EASTERN, size = 40 },
    { name = Z["Molten Core"], low = 60, high = 62, type = RZ_RAID, faction = RZ_CONTESTED, continent = RZ_EASTERN, size = 40 },
    { name = Z["Onyxia's Lair"], low = 60, high = 62, type = RZ_RAID, faction = RZ_CONTESTED, continent = RZ_KALIMDOR, size = 40 },
    { name = Z["Zul'Gurub"], low = 60, high = 62, type = RZ_RAID, faction = RZ_CONTESTED, continent = RZ_EASTERN, size = 20 },
    { name = Z["Ahn'Qiraj"], low = 60, high = 62, type = RZ_RAID, faction = RZ_CONTESTED, continent = RZ_KALIMDOR, size = 20 },
    { name = Z["Temple of Ahn'Qiraj"], low = 60, high = 62, type = RZ_RAID, faction = RZ_CONTESTED, continent = RZ_EASTERN, size = 40 },

-- BC Dungeons
    { name = Z["Hellfire Ramparts"], low = 60, high = 62, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_OUTLAND, heroic = { 70, 74 } },
    { name = Z["The Blood Furnace"], low = 61, high = 63, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_OUTLAND, heroic = { 70, 74 } },
    { name = Z["The Slave Pens"], low = 62, high = 64, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_OUTLAND, heroic = { 70, 74 } },
    { name = Z["The Underbog"], low = 63, high = 65, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_OUTLAND, heroic = { 70, 74 } },
    { name = Z["Auchenai Crypts"], low = 64, high = 66, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_OUTLAND, heroic = { 70, 74 } },
    { name = Z["Shadow Labyrinth"], low = 65, high = 67, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_OUTLAND, heroic = { 70, 74 } },
    { name = Z["Sethekk Halls"], low = 67, high = 69, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_OUTLAND, heroic = { 70, 74 } },
    { name = Z["The Mechanar"], low = 69, high = 72, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_OUTLAND, heroic = { 70, 74 } },
    { name = Z["The Shattered Halls"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_OUTLAND, heroic = { 70, 74 } },
    { name = Z["The Botanica"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_OUTLAND, heroic = { 70, 74 } },
    { name = Z["The Arcatraz"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_OUTLAND, heroic = { 70, 74 } },
    { name = Z["Mana-Tombs"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_OUTLAND, heroic = { 70, 74 } },
    { name = Z["The Steamvault"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_OUTLAND, heroic = { 70, 74 } },
    { name = Z["Magisters' Terrace"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_EASTERN, heroic = { 70, 74 } },
    { name = Z["Old Hillsbrad Foothills"], low = 66, high = 68, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_KALIMDOR, heroic = { 70, 74 } },
    { name = Z["The Black Morass"], low = 68, high = 70, faction = RZ_CONTESTED, type = RZ_INSTANCE, continent = RZ_KALIMDOR, heroic = { 70, 74 } },
-- BC Raids
    { name = Z["The Eye"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_RAID, continent = RZ_OUTLAND, size = 25 },
    { name = Z["Hyjal Summit"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_RAID, continent = RZ_KALIMDOR, size = 25 },
    { name = Z["Karazhan"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_RAID, continent = RZ_EASTERN, size = 10 },
    { name = Z["Gruul's Lair"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_RAID, continent = RZ_OUTLAND, size = 25 },
    { name = Z["Magtheridon's Lair"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_RAID, continent = RZ_OUTLAND, size = 25 },
    { name = Z["Black Temple"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_RAID, continent = RZ_OUTLAND, size = 25 },
    { name = Z["Serpentshrine Cavern"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_RAID, continent = RZ_OUTLAND, size = 25 },
    { name = Z["Sunwell Plateau"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_RAID, continent = RZ_EASTERN, size = 25 },
    { name = Z["Zul'Aman"], low = 70, high = 72, faction = RZ_CONTESTED, type = RZ_RAID, continent = RZ_EASTERN, size = 10 },

-- WotLK Dungeons
    { name = Z["Utgarde Keep"], x = 2, low = 70, high = 72, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_NORTHREND, heroic = { 80, 84 } },
    { name = Z["Utgarde Pinnacle"], low = 80, high = 82, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_NORTHREND, heroic = { 80, 84 } },
    { name = Z["The Oculus"], low = 80, high = 82, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_NORTHREND, heroic = { 80, 84 } },
    { name = Z["The Nexus"], low = 71, high = 73, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_NORTHREND, heroic = { 80, 84 } },
    { name = Z["Azjol-Nerub"], low = 72, high = 74, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_NORTHREND, heroic = { 80, 84 } },
    { name = Z["Ahn'kahet: The Old Kingdom"], low = 73, high = 75, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_NORTHREND, heroic = { 80, 84 } },
    { name = Z["Drak'Tharon Keep"], low = 74, high = 76, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_NORTHREND, heroic = { 80, 84 } },
    { name = Z["The Violet Hold"], low = 75, high = 77, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_NORTHREND, heroic = { 80, 84 } },
    { name = Z["Gundrak"], low = 76, high = 78, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_NORTHREND, heroic = { 80, 84 } },
    { name = Z["Halls of Stone"], low = 77, high = 79, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_NORTHREND, heroic = { 80, 84 } },
    { name = Z["Halls of Lightning"], low = 80, high = 82, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_NORTHREND, heroic = { 80, 84 } },
    { name = Z["The Culling of Stratholme"], low = 80, high = 82, type = RZ_INSTANCE, faction = RZ_CONTESTED, continent = RZ_KALIMDOR, heroic = { 80, 84 } },
-- WotLK Raids
    { name = Z["The Eye of Eternity"], low = 80, high = 82, type = RZ_RAID, faction = RZ_CONTESTED, continent = RZ_NORTHREND, size = { 10, 25 } },
    { name = Z["The Obsidian Sanctum"], low = 80, high = 82, type = RZ_RAID, faction = RZ_CONTESTED, continent = RZ_NORTHREND, size = { 10, 25 } },
    { name = Z["Naxxramas"], low = 80, high = 82, type = RZ_RAID, faction = RZ_CONTESTED, continent = RZ_NORTHREND, size = { 10, 25 } },
    { name = L["Vault of Archavon"], low = 80, high = 82, type = RZ_RAID, faction = RZ_CONTESTED, continent = RZ_NORTHREND, size = { 10, 25 } },
    { name = Z["Icecrown Citadel"], low = 80, high = 82, type = RZ_RAID, faction = RZ_CONTESTED, continent = RZ_NORTHREND, size = { 10, 25 }, NYI = true },
    { name = Z["Ulduar"], x = 2, low = 80, high = 82, type = RZ_RAID, faction = RZ_CONTESTED, continent = RZ_NORTHREND, size = { 10, 25 }, NYI = true },

-- Battlegrounds
    { name = Z["Warsong Gulch"], x = 1, low = 10, high = -1, type = RZ_BATTLEGROUND, faction = RZ_HORDE, continent = RZ_KALIMDOR, size = 10 },
    { name = Z["Warsong Gulch"], x = 2, low = 10, high = -1, type = RZ_BATTLEGROUND, faction = RZ_ALLIANCE, continent = RZ_KALIMDOR, size = 10 },
    { name = Z["Arathi Basin"], low = 20, high = -1, type = RZ_BATTLEGROUND, faction = RZ_CONTESTED, continent = RZ_EASTERN, size = 15 },
    { name = Z["Alterac Valley"], low = 51, high = -1, type = RZ_BATTLEGROUND, faction = RZ_CONTESTED, continent = RZ_EASTERN, size = 40 },
    { name = Z["Eye of the Storm"], low = 61, high = -1, faction = RZ_CONTESTED, type = RZ_BATTLEGROUND, continent = RZ_OUTLAND, size = 15, bracket = true },
    { name = Z["Strand of the Ancients"], low = 71, high = -1, type = RZ_BATTLEGROUND, faction = RZ_CONTESTED, continent = RZ_NORTHREND, size = 15, bracket = true },

-- Towns and transport zones
    { name = Z["Booty Bay"], low = 30, high = 45, faction = RZ_CONTESTED, type = RZ_CITY, continent = RZ_EASTERN },
    { name = Z["Ratchet"], low = 10, high = 25, faction = RZ_CONTESTED, type = RZ_CITY, continent = RZ_KALIMDOR },
    { name = Z["Gadgetzan"], low = 40, high = 50, faction = RZ_CONTESTED, type = RZ_CITY, continent = RZ_KALIMDOR },
    { name = Z["Deeprun Tram"], low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_CITY, continent = RZ_EASTERN },
    { name = Z["Theramore Isle"], low = 35, high = 45, faction = RZ_ALLIANCE, type = RZ_CITY, continent = RZ_KALIMDOR },
    { name = Z["Menethil Harbor"], low = 20, high = 30, faction = RZ_ALLIANCE, type = RZ_CITY, continent = RZ_EASTERN },
    { name = Z["Auberdine"], low = 10, high = 20, faction = RZ_ALLIANCE, type = RZ_CITY, continent = RZ_KALIMDOR },
    { name = Z["Grom'gol Base Camp"], low = 30, high = 45, faction = RZ_HORDE, type = RZ_CITY, continent = RZ_EASTERN },

-- Collections areas for instances
    { name = Z["Blackrock Mountain"], low = 60, high = 62, type = RZ_COLLECTOR, faction = RZ_CONTESTED, continent = RZ_EASTERN },
    { name = Z["Caverns of Time"], low = 66, high = 82, faction = RZ_CONTESTED, type = RZ_COLLECTOR, continent = RZ_KALIMDOR },
    { name = Z["Hellfire Citadel"], low = 60, high = 72, faction = RZ_CONTESTED, type = RZ_COLLECTOR, continent = RZ_OUTLAND },
    { name = Z["The Bone Wastes"], displayname = Z["Auchindoun"], low = 64, high = 72, faction = RZ_CONTESTED, type = RZ_COLLECTOR, continent = RZ_OUTLAND },
    { name = Z["Coilfang Reservoir"], low = 62, high = 72, faction = RZ_CONTESTED, type = RZ_COLLECTOR, continent = RZ_OUTLAND },
    { name = Z["Tempest Keep"], low = 64, high = 72, faction = RZ_CONTESTED, type = RZ_COLLECTOR, continent = RZ_OUTLAND },
    { name = Z["Coldarra"], displayname = Z["The Nexus"], low = 71, high = 82, type = RZ_COLLECTOR, faction = RZ_CONTESTED, continent = RZ_NORTHREND },
    { name = Z["Ulduar"], x = 1, low = 77, high = 82, type = RZ_COLLECTOR, faction = RZ_CONTESTED, continent = RZ_NORTHREND },
    { name = Z["Utgarde Keep"], x = 1, low = 70, high = 82, type = RZ_COLLECTOR, faction = RZ_CONTESTED, continent = RZ_NORTHREND },

-- Transports
    { name = L["Boat"], x = 1, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Boat"], x = 2, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Boat"], x = 3, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Boat"], x = 4, low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Boat"], x = 5, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Boat"], x = 6, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Boat"], x = 7, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Boat"], x = 8, low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Boat"], x = 9, low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 1, low = 70, high = -1, faction = RZ_CONTESTED, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 2, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 3, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 4, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 5, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 6, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 7, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 8, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 9, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 10, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 11, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 12, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 13, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 14, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 15, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 16, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 17, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 18, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 19, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 20, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 21, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 22, low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 24, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 25, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 26, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 27, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 28, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 29, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 30, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 31, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 32, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 33, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 34, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Portal"], x = 35, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Zeppelin"], x = 1, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Zeppelin"], x = 2, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Zeppelin"], x = 3, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Zeppelin"], x = 4, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Zeppelin"], x = 5, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
-- Battlemasters
    { name = L["Battlemaster"], x = 1, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 2, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 3, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 4, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 5, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 6, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 7, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 8, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 9, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 10, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 11, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 12, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 13, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 14, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 15, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 16, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 17, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 18, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 19, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 20, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 21, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 22, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 23, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 24, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 25, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 26, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 27, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 28, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 29, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 30, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 31, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 32, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 33, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 34, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 35, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 36, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 37, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 38, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 39, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 40, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 41, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 42, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 43, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 44, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 45, low = 0, high = 0, faction = RZ_ALLIANCE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 46, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 47, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 48, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 49, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Battlemaster"], x = 50, low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
-- Transport between old and new world
    { name = Z["The Dark Portal"], low = 58, high = -1, faction = RZ_CONTESTED, type = RZ_TRANSPORT, continent = RZ_NOWHERE },
    { name = L["Orb of Translocation"], low = 0, high = 0, faction = RZ_HORDE, type = RZ_TRANSPORT, continent = RZ_NOWHERE },

-- Not real zones
    { name = Z["The Forbidding Sea"], low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_NONE, continent = RZ_EASTERN },
    { name = Z["Twisting Nether"], low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_NONE, continent = RZ_OUTLAND },
    { name = Z["The Great Sea"], low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_NONE, continent = RZ_NOWHERE },
    { name = Z["The North Sea"], low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_NONE, continent = RZ_EASTERN },
    { name = Z["The Veiled Sea"], low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_NONE, continent = RZ_KALIMDOR },
    { name = Z["Hyjal"], low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_NONE, continent = RZ_KALIMDOR },
    { name = Z["The Frozen Sea"], low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_NONE, continent = RZ_NORTHREND },

-- Arenas
    { name = Z["Blade's Edge Arena"], low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_ARENA, continent = RZ_OUTLAND },
    { name = Z["Nagrand Arena"], low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_ARENA, continent = RZ_OUTLAND },
    { name = Z["Ruins of Lordaeron"], low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_ARENA, continent = RZ_EASTERN },
    { name = Z["Dalaran Sewers"], low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_ARENA, continent = RZ_NORTHREND },
    { name = Z["The Ring of Valor"], low = 0, high = 0, faction = RZ_CONTESTED, type = RZ_ARENA, continent = RZ_KALIMDOR },
};
    
local zones = Broker_RecZone.vars.zones;

table.sort( zones,
    function( a, b )
        if( a.high == -1 ) then
            a.high = RZ_MAXLEVEL
        end--if
        if( b.high == -1 ) then
            b.high = RZ_MAXLEVEL
        end--if
        return ( a.low < b.low ) or ( ( a.low == b.low ) and ( a.high < b.high ) ) or ( ( a.low == b.low ) and ( a.high == b.high ) and ( a.name < b.name ) );
    end );

zones[zn( Z["Stormwind City"] )].zones = { zn( Z["Deeprun Tram"] ), zn( Z["Elwynn Forest"] ), zn( Z["The Stockade"] ), zn( L["Boat"], 2 ), zn( L["Boat"], 6 ), zn( L["Battlemaster"], 1 ), zn( L["Battlemaster"], 2 ), zn( L["Battlemaster"], 3 ), zn( L["Battlemaster"], 4 ), zn( L["Battlemaster"], 5 ) };
zones[zn( Z["Ironforge"] )].zones = { zn( Z["Deeprun Tram"] ), zn( Z["Dun Morogh"] ), zn( Z["Isle of Quel'Danas"] ), zn( L["Portal"], 2 ), zn( L["Battlemaster"], 6 ), zn( L["Battlemaster"], 7 ), zn( L["Battlemaster"], 8 ), zn( L["Battlemaster"], 9 ), zn( L["Battlemaster"], 10 ) };
zones[zn( Z["Darnassus"] )].zones = { zn( Z["Teldrassil"] ), zn( L["Boat"], 3 ), zn( L["Battlemaster"], 11 ), zn( L["Battlemaster"], 12 ), zn( L["Battlemaster"], 13 ), zn( L["Battlemaster"], 14 ), zn( L["Battlemaster"], 15 ) };
zones[zn( Z["Undercity"] )].zones = { zn(L["Orb of Translocation"] ), zn( Z["Tirisfal Glades"] ), zn( L["Battlemaster"], 21 ), zn( L["Battlemaster"], 22 ), zn( L["Battlemaster"], 23 ), zn( L["Battlemaster"], 24 ), zn( L["Battlemaster"], 25 ) };
zones[zn( Z["Orgrimmar"] )].zones = { zn( Z["Durotar"] ), zn( Z["Ragefire Chasm"] ), zn( L["Battlemaster"], 26 ), zn( L["Battlemaster"], 27 ), zn( L["Battlemaster"], 28 ), zn( L["Battlemaster"], 29 ), zn( L["Battlemaster"], 30 ) };
zones[zn( Z["Thunder Bluff"] )].zones = { zn( Z["Mulgore"] ), zn( L["Battlemaster"], 31 ), zn( L["Battlemaster"], 32 ), zn( L["Battlemaster"], 33 ), zn( L["Battlemaster"], 34 ), zn( L["Battlemaster"], 35 ) };
zones[zn( Z["Moonglade"] )].zones = { zn( Z["Winterspring"] ), zn( Z["Felwood"] ) };
zones[zn( Z["Dun Morogh"] )].zones = { zn( Z["Ironforge"] ), zn( Z["Loch Modan"] ), zn( Z["Gnomeregan"] ) };
zones[zn( Z["Elwynn Forest"] )].zones = { zn( Z["Stormwind City"] ), zn( Z["Westfall"] ), zn( Z["Redridge Mountains"] ), zn( Z["Duskwood"] ) };
zones[zn( Z["Teldrassil"] )].zones = { zn( Z["Darnassus"] ) };
zones[zn( Z["Tirisfal Glades"] )].zones = { zn( Z["Undercity"] ), zn( Z["Silverpine Forest"] ), zn( Z["Western Plaguelands"] ), zn( L["Zeppelin"], 1 ), zn( L["Zeppelin"], 2 ), zn( Z["Scarlet Monastery"] ), zn( L["Zeppelin"], 5 ) };
zones[zn( Z["Durotar"] )].zones = { zn( Z["Orgrimmar"] ), zn( Z["The Barrens"] ), zn( Z["Azshara"] ), zn( L["Zeppelin"], 1 ), zn( L["Zeppelin"], 3 ), zn( L["Zeppelin"], 4 ) };
zones[zn( Z["Mulgore"] )].zones = { zn( Z["Thunder Bluff"] ), zn( Z["The Barrens"] ) };
zones[zn( Z["Loch Modan"] )].zones = { zn( Z["Dun Morogh"] ), zn( Z["Wetlands"] ), zn( Z["Badlands"] ) };
zones[zn( Z["Westfall"] )].zones = { zn( Z["Elwynn Forest"] ), zn( Z["Duskwood"] ), zn( Z["The Deadmines"] ) };
zones[zn( Z["Silverpine Forest"] )].zones = { zn( Z["Tirisfal Glades"] ), zn( Z["Hillsbrad Foothills"] ), zn( Z["Alterac Mountains"] ), zn( Z["Shadowfang Keep"] ) };
zones[zn( Z["Darkshore"] )].zones = { zn( Z["Ashenvale"] ), zn( Z["Auberdine"] ) };
zones[zn( Z["The Barrens"] )].zones = { zn( Z["Ratchet"] ), zn( Z["Durotar"] ), zn( Z["Mulgore"] ), zn( Z["Stonetalon Mountains"] ), zn( Z["Ashenvale"] ), zn( Z["Thousand Needles"] ), zn( Z["Dustwallow Marsh"] ), zn( Z["Wailing Caverns"] ), zn( Z["Razorfen Kraul"] ), zn( Z["Razorfen Downs"] ), zn( Z["Warsong Gulch"], 1 ) };
zones[zn( Z["Redridge Mountains"] )].zones = { zn( Z["Elwynn Forest"] ), zn( Z["Burning Steppes"] ) };
zones[zn( Z["Stonetalon Mountains"] )].zones = { zn( Z["The Barrens"] ), zn( Z["Ashenvale"] ), zn( Z["Desolace"] ) };
zones[zn( Z["Ashenvale"] )].zones = { zn( Z["Darkshore"] ), zn( Z["The Barrens"] ), zn( Z["Stonetalon Mountains"] ), zn( Z["Azshara"] ), zn( Z["Felwood"] ), zn( Z["Blackfathom Deeps"] ), zn( Z["Warsong Gulch"], 2 ) };
zones[zn( Z["Wetlands"] )].zones = { zn( Z["Loch Modan"] ), zn( Z["Arathi Highlands"] ), zn( Z["Menethil Harbor"] ) };
zones[zn( Z["Duskwood"] )].zones = { zn( Z["Elwynn Forest"] ), zn( Z["Westfall"] ), zn( Z["Stranglethorn Vale"] ), zn( Z["Deadwind Pass"] ) };
zones[zn( Z["Hillsbrad Foothills"] )].zones = { zn( Z["Silverpine Forest"] ), zn( Z["Alterac Mountains"] ), zn( Z["Arathi Highlands"] ) };
zones[zn( Z["Thousand Needles"] )].zones = { zn( Z["The Barrens"] ), zn( Z["Feralas"] ), zn( Z["Tanaris"] ) };
zones[zn( Z["Alterac Mountains"] )].zones = { zn( Z["Silverpine Forest"] ), zn( Z["Hillsbrad Foothills"] ), zn( Z["The Hinterlands"] ), zn( Z["Western Plaguelands"] ), zn( Z["Alterac Valley"] ) };
zones[zn( Z["Arathi Highlands"] )].zones = { zn( Z["Wetlands"] ), zn( Z["Hillsbrad Foothills"] ), zn( Z["Arathi Basin"] ) };
zones[zn( Z["Desolace"] )].zones = { zn( Z["Stonetalon Mountains"] ), zn( Z["Feralas"] ), zn( Z["Maraudon"] ) };
zones[zn( Z["Stranglethorn Vale"] )].zones = { zn( Z["Booty Bay"] ), zn( Z["Duskwood"] ), zn( Z["Grom'gol Base Camp"] ), zn( Z["Zul'Gurub"] ) };
zones[zn( Z["Badlands"] )].zones = { zn( Z["Loch Modan"] ), zn( Z["Searing Gorge"] ), zn( Z["Uldaman"] ) };
zones[zn( Z["Swamp of Sorrows"] )].zones = { zn( Z["Blasted Lands"] ), zn( Z["Deadwind Pass"] ), zn( Z["The Temple of Atal'Hakkar"] ) };
zones[zn( Z["Dustwallow Marsh"] )].zones = { zn( Z["The Barrens"] ), zn( Z["Theramore Isle"] ), zn( Z["Onyxia's Lair"] ) };
zones[zn( Z["The Hinterlands"] )].zones = { zn( Z["Alterac Mountains"] ), zn( Z["Western Plaguelands"] ) };
zones[zn( Z["Feralas"] )].zones = { zn( Z["Thousand Needles"] ), zn( Z["Desolace"] ), zn( Z["Dire Maul"] ) };
zones[zn( Z["Tanaris"] )].zones = { zn( Z["Thousand Needles"] ), zn( Z["Un'Goro Crater"] ), zn( Z["Gadgetzan"] ), zn( Z["Zul'Farrak"] ), zn( Z["Caverns of Time"] ) };
zones[zn( Z["Searing Gorge"] )].zones = { zn( Z["Badlands"] ), zn( Z["Blackrock Mountain"] ) };
zones[zn( Z["Blasted Lands"] )].zones = { zn( Z["Swamp of Sorrows"] ), zn( Z["The Dark Portal"] ) };
zones[zn( Z["Un'Goro Crater"] )].zones = { zn( Z["Tanaris"] ), zn( Z["Silithus"] ) };
zones[zn( Z["Azshara"] )].zones = { zn( Z["Durotar"] ), zn( Z["Ashenvale"] ) };
zones[zn( Z["Felwood"] )].zones = { zn( Z["Darkshore"] ), zn( Z["Ashenvale"] ), zn( Z["Winterspring"] ), zn( Z["Moonglade"] ) };
zones[zn( Z["Burning Steppes"] )].zones = { zn( Z["Redridge Mountains"] ), zn( Z["Blackrock Mountain"] ) };
zones[zn( Z["Western Plaguelands"] )].zones = { zn( Z["Tirisfal Glades"] ), zn( Z["Alterac Mountains"] ), zn( Z["The Hinterlands"] ), zn( Z["Eastern Plaguelands"] ), zn( Z["Scholomance"] ) };
zones[zn( Z["Deadwind Pass"] )].zones = { zn( Z["Duskwood"] ), zn( Z["Swamp of Sorrows"] ), zn( Z["Karazhan"] ) };
zones[zn( Z["Karazhan"] )].zones = { zn( Z["Deadwind Pass"] ) };
zones[zn( Z["Eastern Plaguelands"] )].zones = { zn( Z["Western Plaguelands"] ), zn( Z["Stratholme"] ), zn( Z["Ghostlands"] ) };
zones[zn( Z["Silithus"] )].zones = { zn( Z["Un'Goro Crater"] ), zn( Z["Ahn'Qiraj"] ), zn( Z["Temple of Ahn'Qiraj"] ) };
zones[zn( Z["Winterspring"] )].zones = { zn( Z["Moonglade"] ), zn( Z["Felwood"] ) };

zones[zn( Z["Silvermoon City"] )].zones = { zn( Z["Eversong Woods"] ), zn(L["Orb of Translocation"] ), zn( Z["Isle of Quel'Danas"] ), zn( L["Battlemaster"], 36 ), zn( L["Battlemaster"], 37 ), zn( L["Battlemaster"], 38 ), zn( L["Battlemaster"], 39 ), zn( L["Battlemaster"], 40 ) };
zones[zn( Z["Eversong Woods"] )].zones = { zn( Z["Ghostlands"] ), zn( Z["Silvermoon City"] ) };
zones[zn( Z["Ghostlands"] )].zones = { zn( Z["Eversong Woods"] ), zn( Z["Eastern Plaguelands"] ), zn( Z["Zul'Aman"] ) };

zones[zn( Z["Auberdine"] )].zones = { zn( Z["Darkshore"] ), zn( L["Boat"], 2 ), zn( L["Boat"], 3 ), zn( L["Boat"], 5 ) };
zones[zn( Z["Azuremyst Isle"] )].zones = { zn( Z["Bloodmyst Isle"] ), zn( Z["The Exodar"] ), zn( L["Boat"], 5 ) };
zones[zn( Z["Bloodmyst Isle"] )].zones = { zn( Z["Azuremyst Isle"] ) };
zones[zn( Z["The Exodar"] )].zones = { zn( Z["Azuremyst Isle"] ), zn( L["Battlemaster"], 16 ), zn( L["Battlemaster"], 17 ), zn( L["Battlemaster"], 18 ), zn( L["Battlemaster"], 19 ), zn( L["Battlemaster"], 20 ) };

zones[zn( Z["Shattrath City"] )].zones = { zn( Z["Terokkar Forest"] ), zn( L["Portal"], 1 ), zn( L["Portal"], 2 ), zn( L["Portal"], 3 ), zn( L["Portal"], 4 ), zn( L["Portal"], 5 ), zn( L["Portal"], 6 ), zn( L["Portal"], 7 ), zn( L["Portal"], 8 ), zn( L["Portal"], 9 ), zn( L["Battlemaster"], 41 ), zn( L["Battlemaster"], 42 ), zn( L["Battlemaster"], 43 ), zn( L["Battlemaster"], 44 ), zn( L["Battlemaster"], 45 ), zn( L["Battlemaster"], 46 ), zn( L["Battlemaster"], 47 ), zn( L["Battlemaster"], 48 ), zn( L["Battlemaster"], 49 ), zn( L["Battlemaster"], 50 ) };
zones[zn( Z["Hellfire Peninsula"] )].zones = { zn( Z["Zangarmarsh"] ), zn( Z["Terokkar Forest"] ), zn( Z["Hellfire Citadel"] ), zn( Z["The Dark Portal"] ) };
zones[zn( Z["Zangarmarsh"] )].zones = { zn( Z["Hellfire Peninsula"] ), zn( Z["Terokkar Forest"] ), zn( Z["Nagrand"] ), zn( Z["Blade's Edge Mountains"] ), zn( Z["Coilfang Reservoir"] ) };
zones[zn( Z["Terokkar Forest"] )].zones = { zn( Z["Hellfire Peninsula"] ), zn( Z["Zangarmarsh"] ), zn( Z["Nagrand"] ), zn( Z["Shadowmoon Valley"] ), zn( Z["The Bone Wastes"] ), zn( Z["Shattrath City"] ) };
zones[zn( Z["Nagrand"] )].zones = { zn( Z["Zangarmarsh"] ), zn( Z["Terokkar Forest"] ) };
zones[zn( Z["Blade's Edge Mountains"] )].zones = { zn( Z["Zangarmarsh"] ), zn( Z["Netherstorm"] ), zn( Z["Gruul's Lair"] ) };
zones[zn( Z["Netherstorm"] )].zones = { zn( Z["Blade's Edge Mountains"] ), zn( Z["Tempest Keep"] ) };
zones[zn( Z["Shadowmoon Valley"] )].zones = { zn( Z["Terokkar Forest"] ), zn( Z["Black Temple"] ) };

zones[zn( Z["Ragefire Chasm"] )].zones = { zn( Z["Orgrimmar"] ) };
zones[zn( Z["Wailing Caverns"] )].zones = { zn( Z["The Barrens"] ) };
zones[zn( Z["The Deadmines"] )].zones = { zn( Z["Westfall"] ) };
zones[zn( Z["The Stockade"] )].zones = { zn( Z["Stormwind City"] ) };
zones[zn( Z["Shadowfang Keep"] )].zones = { zn( Z["Silverpine Forest"] ) };
zones[zn( Z["Blackfathom Deeps"] )].zones = { zn( Z["Ashenvale"] ) };
zones[zn( Z["Gnomeregan"] )].zones = { zn( Z["Dun Morogh"] ) };
zones[zn( Z["Razorfen Kraul"] )].zones = { zn( Z["The Barrens"] ) };
zones[zn( Z["Scarlet Monastery"] )].zones = { zn( Z["Tirisfal Glades"] ) };
zones[zn( Z["Razorfen Downs"] )].zones = { zn( Z["The Barrens"] ) };
zones[zn( Z["Uldaman"] )].zones = { zn( Z["Badlands"] ) };
zones[zn( Z["Maraudon"] )].zones = { zn( Z["Desolace"] ) };
zones[zn( Z["Zul'Farrak"] )].zones = { zn( Z["Tanaris"] ) };
zones[zn( Z["The Temple of Atal'Hakkar"] )].zones = { zn( Z["Swamp of Sorrows"] ) };
zones[zn( Z["Blackrock Depths"] )].zones = { zn( Z["Blackrock Mountain"] ), zn( Z["Molten Core"] ) };
zones[zn( Z["Blackrock Spire"] )].zones = { zn( Z["Blackrock Mountain"] ), zn( Z["Blackwing Lair"] ) };
zones[zn( Z["Stratholme"] )].zones = { zn( Z["Eastern Plaguelands"] ) };
zones[zn( Z["Dire Maul"] )].zones = { zn( Z["Feralas"] ) };
zones[zn( Z["Scholomance"] )].zones = { zn( Z["Western Plaguelands"] ) };
zones[zn( Z["Warsong Gulch"], 1 )].zones = { zn( Z["The Barrens"] ) };
zones[zn( Z["Warsong Gulch"], 2 )].zones = { zn( Z["Ashenvale"] ) };
zones[zn( Z["Arathi Basin"] )].zones = { zn( Z["Arathi Highlands"] ) };
zones[zn( Z["Alterac Valley"] )].zones = { zn( Z["Alterac Mountains"] ) };
zones[zn( Z["Blackwing Lair"] )].zones = { zn( Z["Blackrock Spire"] ) };
zones[zn( Z["Molten Core"] )].zones = { zn( Z["Blackrock Depths"] ) };
zones[zn( Z["Onyxia's Lair"] )].zones = { zn( Z["Dustwallow Marsh"] ) };
zones[zn( Z["Zul'Gurub"] )].zones = { zn( Z["Stranglethorn Vale"] ) };
zones[zn( Z["Ahn'Qiraj"] )].zones = { zn( Z["Silithus"] ) };
zones[zn( Z["Temple of Ahn'Qiraj"] )].zones = { zn( Z["Silithus"] ) };
zones[zn( Z["Zul'Aman"] )].zones = { zn( Z["Ghostlands"] ) };

zones[zn( Z["Caverns of Time"] )].zones = { zn( Z["Tanaris"] ), zn( Z["Old Hillsbrad Foothills"] ), zn( Z["The Black Morass"] ), zn( Z["Hyjal Summit"] ), zn( Z["The Culling of Stratholme"] ) };
zones[zn( Z["Old Hillsbrad Foothills"] )].zones = { zn( Z["Caverns of Time"] ) };
zones[zn( Z["The Black Morass"] )].zones = { zn( Z["Caverns of Time"] ) };
zones[zn( Z["Hyjal Summit"] )].zones = { zn( Z["Caverns of Time"] ) };
zones[zn( Z["The Culling of Stratholme"] )].zones = { zn( Z["Caverns of Time"] ) };

zones[zn( Z["Hellfire Citadel"] )].zones = { zn( Z["Hellfire Peninsula"] ), zn( Z["Hellfire Ramparts"] ), zn( Z["The Blood Furnace"] ), zn( Z["The Shattered Halls"] ), zn( Z["Magtheridon's Lair"] ) };
zones[zn( Z["Hellfire Ramparts"] )].zones = { zn( Z["Hellfire Citadel"] ) };
zones[zn( Z["The Blood Furnace"] )].zones = { zn( Z["Hellfire Citadel"] ) };
zones[zn( Z["The Shattered Halls"] )].zones = { zn( Z["Hellfire Citadel"] ) };
zones[zn( Z["Magtheridon's Lair"] )].zones = { zn( Z["Hellfire Citadel"] ) };

zones[zn( Z["Tempest Keep"] )].zones = { zn( Z["Netherstorm"] ), zn( Z["The Mechanar"] ), zn( Z["The Botanica"] ), zn( Z["The Arcatraz"] ), zn( Z["The Eye"] ) };
zones[zn( Z["The Mechanar"] )].zones = { zn( Z["Tempest Keep"] ) };
zones[zn( Z["The Botanica"] )].zones = { zn( Z["Tempest Keep"] ) };
zones[zn( Z["The Arcatraz"] )].zones = { zn( Z["Tempest Keep"] ) };
zones[zn( Z["The Eye"] )].zones = { zn( Z["Tempest Keep"] ) };

zones[zn( Z["Coilfang Reservoir"] )].zones = { zn( Z["Zangarmarsh"] ), zn( Z["The Slave Pens"] ), zn( Z["The Underbog"] ), zn( Z["The Steamvault"] ), zn( Z["Serpentshrine Cavern"] ) };
zones[zn( Z["The Slave Pens"] )].zones = { zn( Z["Coilfang Reservoir"] ) };
zones[zn( Z["The Underbog"] )].zones = { zn( Z["Coilfang Reservoir"] ) };
zones[zn( Z["The Steamvault"] )].zones = { zn( Z["Coilfang Reservoir"] ) };
zones[zn( Z["Serpentshrine Cavern"] )].zones = { zn( Z["Coilfang Reservoir"] ) };

zones[zn( Z["The Bone Wastes"] )].zones = { zn( Z["Terokkar Forest"] ), zn( Z["Auchenai Crypts"] ), zn( Z["Shadow Labyrinth"] ), zn( Z["Sethekk Halls"] ), zn( Z["Mana-Tombs"] ) };
zones[zn( Z["Auchenai Crypts"] )].zones = { zn( Z["The Bone Wastes"] ) };
zones[zn( Z["Shadow Labyrinth"] )].zones = { zn( Z["The Bone Wastes"] ) };
zones[zn( Z["Sethekk Halls"] )].zones = { zn( Z["The Bone Wastes"] ) };
zones[zn( Z["Mana-Tombs"] )].zones = { zn( Z["The Bone Wastes"] ) };

zones[zn( Z["Gruul's Lair"] )].zones = { zn( Z["Blade's Edge Mountains"] ) };
zones[zn( Z["Black Temple"] )].zones = { zn( Z["Shadowmoon Valley"] ) };

--["Isle of Quel'Danas"]
zones[zn( Z["Isle of Quel'Danas"] )].zones = { zn( Z["Magisters' Terrace"] ), zn( Z["Sunwell Plateau"] ), zn( Z["Ironforge"] ), zn( Z["Silvermoon City"] ) };
zones[zn( Z["Magisters' Terrace"] )].zones = { zn( Z["Isle of Quel'Danas"] ) };
zones[zn( Z["Sunwell Plateau"] )].zones = { zn( Z["Isle of Quel'Danas"] ) };

zones[zn( Z["Gadgetzan"] )].zones = { zn( Z["Tanaris"] ) };
zones[zn( Z["Deeprun Tram"] )].zones = { zn( Z["Stormwind City"] ), zn( Z["Ironforge"] ) };
zones[zn( Z["Theramore Isle"] )].zones = { zn( Z["Dustwallow Marsh"] ), zn( L["Boat"], 1 ) };
zones[zn( Z["Booty Bay"] )].zones = { zn( Z["Stranglethorn Vale"] ), zn( L["Boat"], 4 ) };
zones[zn( Z["Ratchet"] )].zones = { zn( Z["The Barrens"] ), zn( L["Boat"], 4 ) };
zones[zn( Z["Menethil Harbor"] )].zones = { zn( Z["Wetlands"] ), zn( L["Boat"], 1 ), zn( L["Boat"], 7 ) };
zones[zn( Z["Auberdine"] )].zones = { zn( Z["Darkshore"] ), zn( L["Boat"], 2 ), zn( L["Boat"], 3 ) };
zones[zn( Z["Grom'gol Base Camp"] )].zones = { zn( Z["Stranglethorn Vale"] ), zn( L["Zeppelin"], 2 ), zn( L["Zeppelin"], 3 ) };
zones[zn( Z["Blackrock Mountain"] )].zones = { zn( Z["Searing Gorge"] ), zn( Z["Burning Steppes"] ), zn( Z["Blackrock Depths"] ), zn( Z["Blackrock Spire"] ) };

zones[zn( L["Portal"], 1 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Isle of Quel'Danas"] ) };
zones[zn( L["Portal"], 2 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Ironforge"] ) };
zones[zn( L["Portal"], 3 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Stormwind City"] ) };
zones[zn( L["Portal"], 4 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Darnassus"] ) };
zones[zn( L["Portal"], 5 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Undercity"] ) };
zones[zn( L["Portal"], 6 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Orgrimmar"] ) };
zones[zn( L["Portal"], 7 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Thunder Bluff"] ) };
zones[zn( L["Portal"], 8 )].zones = { zn( Z["Shattrath City"] ), zn( Z["The Exodar"] ) };
zones[zn( L["Portal"], 9 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Silvermoon City"] ) };
zones[zn( L["Portal"], 10 )].zones = { zn( Z["Dalaran"] ), zn( Z["Ironforge"] ) };
zones[zn( L["Portal"], 11 )].zones = { zn( Z["Dalaran"] ), zn( Z["Stormwind City"] ) };
zones[zn( L["Portal"], 12 )].zones = { zn( Z["Dalaran"] ), zn( Z["Darnassus"] ) };
zones[zn( L["Portal"], 13 )].zones = { zn( Z["Dalaran"] ), zn( Z["The Exodar"] ) };
zones[zn( L["Portal"], 14 )].zones = { zn( Z["Dalaran"] ), zn( Z["Shattrath City"] ) };
zones[zn( L["Portal"], 15 )].zones = { zn( Z["Dalaran"] ), zn( Z["Undercity"] ) };
zones[zn( L["Portal"], 16 )].zones = { zn( Z["Dalaran"] ), zn( Z["Orgrimmar"] ) };
zones[zn( L["Portal"], 17 )].zones = { zn( Z["Dalaran"] ), zn( Z["Thunder Bluff"] ) };
zones[zn( L["Portal"], 18 )].zones = { zn( Z["Dalaran"] ), zn( Z["Silvermoon City"] ) };
zones[zn( L["Portal"], 19 )].zones = { zn( Z["Dalaran"] ), zn( Z["Shattrath City"] ) };
zones[zn( L["Portal"], 20 )].zones = { zn( Z["Dalaran"] ), zn( Z["Wintergrasp"] ) };
zones[zn( L["Portal"], 21 )].zones = { zn( Z["Dalaran"] ), zn( Z["Wintergrasp"] ) };
zones[zn( L["Portal"], 22 )].zones = { zn( Z["Dalaran"] ), zn( Z["Caverns of Time"] ) };
zones[zn( L["Portal"], 24 )].zones = { zn( Z["Dalaran"] ), zn( Z["Warsong Gulch"], 2 ) };
zones[zn( L["Portal"], 25 )].zones = { zn( Z["Dalaran"] ), zn( Z["Arathi Basin"] ) };
zones[zn( L["Portal"], 26 )].zones = { zn( Z["Dalaran"] ), zn( Z["Alterac Valley"] ) };
zones[zn( L["Portal"], 27 )].zones = { zn( Z["Dalaran"] ), zn( Z["Eye of the Storm"] ) };
zones[zn( L["Portal"], 28 )].zones = { zn( Z["Dalaran"] ), zn( Z["Strand of the Ancients"] ) };
zones[zn( L["Portal"], 29 )].zones = { zn( Z["Dalaran"] ), zn( Z["Warsong Gulch"], 1 ) };
zones[zn( L["Portal"], 30 )].zones = { zn( Z["Dalaran"] ), zn( Z["Arathi Basin"] ) };
zones[zn( L["Portal"], 31 )].zones = { zn( Z["Dalaran"] ), zn( Z["Alterac Valley"] ) };
zones[zn( L["Portal"], 32 )].zones = { zn( Z["Dalaran"] ), zn( Z["Eye of the Storm"] ) };
zones[zn( L["Portal"], 33 )].zones = { zn( Z["Dalaran"] ), zn( Z["Strand of the Ancients"] ) };
zones[zn( L["Portal"], 34 )].zones = { zn( Z["Dalaran"] ), zn( L["Vault of Archavon"] ) };
zones[zn( L["Portal"], 35 )].zones = { zn( Z["Dalaran"] ), zn( L["Vault of Archavon"] ) };

zones[zn( L["Battlemaster"], 1 )].zones = { zn( Z["Stormwind City"] ), zn( Z["Warsong Gulch"], 2 ) };
zones[zn( L["Battlemaster"], 2 )].zones = { zn( Z["Stormwind City"] ), zn( Z["Arathi Basin"] ) };
zones[zn( L["Battlemaster"], 3 )].zones = { zn( Z["Stormwind City"] ), zn( Z["Alterac Valley"] ) };
zones[zn( L["Battlemaster"], 4 )].zones = { zn( Z["Stormwind City"] ), zn( Z["Eye of the Storm"] ) };
zones[zn( L["Battlemaster"], 5 )].zones = { zn( Z["Stormwind City"] ), zn( Z["Strand of the Ancients"] ) };
zones[zn( L["Battlemaster"], 6 )].zones = { zn( Z["Ironforge"] ), zn( Z["Warsong Gulch"], 2 ) };
zones[zn( L["Battlemaster"], 7 )].zones = { zn( Z["Ironforge"] ), zn( Z["Arathi Basin"] ) };
zones[zn( L["Battlemaster"], 8 )].zones = { zn( Z["Ironforge"] ), zn( Z["Alterac Valley"] ) };
zones[zn( L["Battlemaster"], 9 )].zones = { zn( Z["Ironforge"] ), zn( Z["Eye of the Storm"] ) };
zones[zn( L["Battlemaster"], 10 )].zones = { zn( Z["Ironforge"] ), zn( Z["Strand of the Ancients"] ) };
zones[zn( L["Battlemaster"], 11 )].zones = { zn( Z["Darnassus"] ), zn( Z["Warsong Gulch"], 2 ) };
zones[zn( L["Battlemaster"], 12 )].zones = { zn( Z["Darnassus"] ), zn( Z["Arathi Basin"] ) };
zones[zn( L["Battlemaster"], 13 )].zones = { zn( Z["Darnassus"] ), zn( Z["Alterac Valley"] ) };
zones[zn( L["Battlemaster"], 14 )].zones = { zn( Z["Darnassus"] ), zn( Z["Eye of the Storm"] ) };
zones[zn( L["Battlemaster"], 15 )].zones = { zn( Z["Darnassus"] ), zn( Z["Strand of the Ancients"] ) };
zones[zn( L["Battlemaster"], 16 )].zones = { zn( Z["The Exodar"] ), zn( Z["Warsong Gulch"], 2 ) };
zones[zn( L["Battlemaster"], 17 )].zones = { zn( Z["The Exodar"] ), zn( Z["Arathi Basin"] ) };
zones[zn( L["Battlemaster"], 18 )].zones = { zn( Z["The Exodar"] ), zn( Z["Alterac Valley"] ) };
zones[zn( L["Battlemaster"], 19 )].zones = { zn( Z["The Exodar"] ), zn( Z["Eye of the Storm"] ) };
zones[zn( L["Battlemaster"], 20 )].zones = { zn( Z["The Exodar"] ), zn( Z["Strand of the Ancients"] ) };
zones[zn( L["Battlemaster"], 21 )].zones = { zn( Z["Undercity"] ), zn( Z["Warsong Gulch"], 1 ) };
zones[zn( L["Battlemaster"], 22 )].zones = { zn( Z["Undercity"] ), zn( Z["Arathi Basin"] ) };
zones[zn( L["Battlemaster"], 23 )].zones = { zn( Z["Undercity"] ), zn( Z["Alterac Valley"] ) };
zones[zn( L["Battlemaster"], 24 )].zones = { zn( Z["Undercity"] ), zn( Z["Eye of the Storm"] ) };
zones[zn( L["Battlemaster"], 25 )].zones = { zn( Z["Undercity"] ), zn( Z["Strand of the Ancients"] ) };
zones[zn( L["Battlemaster"], 26 )].zones = { zn( Z["Orgrimmar"] ), zn( Z["Warsong Gulch"], 1 ) };
zones[zn( L["Battlemaster"], 27 )].zones = { zn( Z["Orgrimmar"] ), zn( Z["Arathi Basin"] ) };
zones[zn( L["Battlemaster"], 28 )].zones = { zn( Z["Orgrimmar"] ), zn( Z["Alterac Valley"] ) };
zones[zn( L["Battlemaster"], 29 )].zones = { zn( Z["Orgrimmar"] ), zn( Z["Eye of the Storm"] ) };
zones[zn( L["Battlemaster"], 30 )].zones = { zn( Z["Orgrimmar"] ), zn( Z["Strand of the Ancients"] ) };
zones[zn( L["Battlemaster"], 31 )].zones = { zn( Z["Thunder Bluff"] ), zn( Z["Warsong Gulch"], 1 ) };
zones[zn( L["Battlemaster"], 32 )].zones = { zn( Z["Thunder Bluff"] ), zn( Z["Arathi Basin"] ) };
zones[zn( L["Battlemaster"], 33 )].zones = { zn( Z["Thunder Bluff"] ), zn( Z["Alterac Valley"] ) };
zones[zn( L["Battlemaster"], 34 )].zones = { zn( Z["Thunder Bluff"] ), zn( Z["Eye of the Storm"] ) };
zones[zn( L["Battlemaster"], 35 )].zones = { zn( Z["Thunder Bluff"] ), zn( Z["Strand of the Ancients"] ) };
zones[zn( L["Battlemaster"], 36 )].zones = { zn( Z["Silvermoon City"] ), zn( Z["Warsong Gulch"], 1 ) };
zones[zn( L["Battlemaster"], 37 )].zones = { zn( Z["Silvermoon City"] ), zn( Z["Arathi Basin"] ) };
zones[zn( L["Battlemaster"], 38 )].zones = { zn( Z["Silvermoon City"] ), zn( Z["Alterac Valley"] ) };
zones[zn( L["Battlemaster"], 39 )].zones = { zn( Z["Silvermoon City"] ), zn( Z["Eye of the Storm"] ) };
zones[zn( L["Battlemaster"], 40 )].zones = { zn( Z["Silvermoon City"] ), zn( Z["Strand of the Ancients"] ) };
zones[zn( L["Battlemaster"], 41 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Warsong Gulch"], 2 ) };
zones[zn( L["Battlemaster"], 42 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Arathi Basin"] ) };
zones[zn( L["Battlemaster"], 43 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Alterac Valley"] ) };
zones[zn( L["Battlemaster"], 44 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Eye of the Storm"] ) };
zones[zn( L["Battlemaster"], 45 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Strand of the Ancients"] ) };
zones[zn( L["Battlemaster"], 46 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Warsong Gulch"], 1 ) };
zones[zn( L["Battlemaster"], 47 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Arathi Basin"] ) };
zones[zn( L["Battlemaster"], 48 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Alterac Valley"] ) };
zones[zn( L["Battlemaster"], 49 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Eye of the Storm"] ) };
zones[zn( L["Battlemaster"], 50 )].zones = { zn( Z["Shattrath City"] ), zn( Z["Strand of the Ancients"] ) };

zones[zn( L["Boat"], 1 )].zones = { zn( Z["Theramore Isle"] ), zn( Z["Menethil Harbor"] ) };
zones[zn( L["Boat"], 2 )].zones = { zn( Z["Stormwind City"] ), zn( Z["Auberdine"] ) };
zones[zn( L["Boat"], 3 )].zones = { zn( Z["Darnassus"] ), zn( Z["Auberdine"] ) };
zones[zn( L["Boat"], 4 )].zones = { zn( Z["Booty Bay"] ), zn( Z["Ratchet"] ) };
zones[zn( L["Boat"], 5 )].zones = { zn( Z["Azuremyst Isle"] ), zn( Z["Auberdine"] ) };
zones[zn( L["Boat"], 6 )].zones = { zn( Z["Stormwind City"] ), zn( Z["Borean Tundra"] ) };
zones[zn( L["Boat"], 7 )].zones = { zn( Z["Menethil Harbor"] ), zn( Z["Howling Fjord"] ) };
zones[zn( L["Boat"], 8 )].zones = { zn( Z["Borean Tundra"] ), zn( Z["Dragonblight"] ) };
zones[zn( L["Boat"], 9 )].zones = { zn( Z["Howling Fjord"] ), zn( Z["Dragonblight"] ) };
zones[zn( L["Zeppelin"], 1 )].zones = { zn( Z["Tirisfal Glades"] ), zn( Z["Durotar"] ) };
zones[zn( L["Zeppelin"], 2 )].zones = { zn( Z["Tirisfal Glades"] ), zn( Z["Grom'gol Base Camp"] ) };
zones[zn( L["Zeppelin"], 3 )].zones = { zn( Z["Durotar"] ), zn( Z["Grom'gol Base Camp"] ) };
zones[zn( L["Zeppelin"], 4 )].zones = { zn( Z["Durotar"] ), zn( Z["Borean Tundra"] ) };
zones[zn( L["Zeppelin"], 5 )].zones = { zn( Z["Tirisfal Glades"] ), zn( Z["Howling Fjord"] ) };
zones[zn(L["Orb of Translocation"] )].zones = { zn( Z["Silvermoon City"] ), zn( Z["Undercity"] ) };
zones[zn( Z["The Dark Portal"] )].zones = { zn( Z["Hellfire Peninsula"] ), zn( Z["Blasted Lands"] ) };

--Northrend
zones[zn( Z["Howling Fjord"] )].zones = { zn( Z["Grizzly Hills"] ), zn( Z["Utgarde Keep"], 1 ), zn( L["Zeppelin"], 6 ), zn( L["Boat"], 9 ) };
zones[zn( Z["Utgarde Keep"], 1 )].zones = { zn( Z["Howling Fjord"] ), zn( Z["Utgarde Keep"], 2 ), zn( Z["Utgarde Pinnacle"] ) };
zones[zn( Z["Utgarde Keep"], 2 )].zones = { zn( Z["Utgarde Keep"], 1 ) };
zones[zn( Z["Utgarde Pinnacle"] )].zones = { zn( Z["Utgarde Keep"], 1 ) };

zones[zn( Z["Borean Tundra"] )].zones = { zn( Z["Dragonblight"] ), zn( Z["Sholazar Basin"] ), zn( Z["Coldarra"] ), zn( L["Boat"], 8 ), zn( L["Zeppelin"], 6 ) };
zones[zn( Z["Coldarra"] )].zones = { zn( Z["Borean Tundra"] ), zn( Z["The Nexus"] ), zn( Z["The Oculus"] ), zn( Z["The Eye of Eternity"] ) };
zones[zn( Z["The Nexus"] )].zones = { zn( Z["Coldarra"] ) };
zones[zn( Z["The Oculus"] )].zones = { zn( Z["Coldarra"] ) };
zones[zn( Z["The Eye of Eternity"] )].zones = { zn( Z["Coldarra"] ) };

zones[zn( Z["Dragonblight"] )].zones = { zn( Z["Borean Tundra"] ), zn( Z["Zul'Drak"] ), zn( Z["Grizzly Hills"] ), zn( Z["Crystalsong Forest"] ), zn( Z["Azjol-Nerub"] ), zn( Z["Ahn'kahet: The Old Kingdom"] ), zn( Z["The Obsidian Sanctum"] ), zn( Z["Naxxramas"] ) };
zones[zn( Z["Azjol-Nerub"] )].zones = { zn( Z["Dragonblight"] ) };
zones[zn( Z["Ahn'kahet: The Old Kingdom"] )].zones = { zn( Z["Dragonblight"] ) };
zones[zn( Z["The Obsidian Sanctum"] )].zones = { zn( Z["Dragonblight"] ) };
zones[zn( Z["Naxxramas"] )].zones = { zn( Z["Dragonblight"] ) };

zones[zn( Z["Grizzly Hills"] )].zones = { zn( Z["Howling Fjord"] ), zn( Z["Zul'Drak"] ), zn( Z["Dragonblight"] ), zn( Z["Drak'Tharon Keep"] ) };
zones[zn( Z["Drak'Tharon Keep"] )].zones = { zn( Z["Grizzly Hills"] ) };

zones[zn( Z["Zul'Drak"] )].zones = { zn( Z["Grizzly Hills"] ), zn( Z["Crystalsong Forest"] ), zn( Z["Dragonblight"] ), zn( Z["Gundrak"] ) };
zones[zn( Z["Gundrak"] )].zones = { zn( Z["Zul'Drak"] ) };

zones[zn( Z["Sholazar Basin"] )].zones = { zn( Z["Borean Tundra"] ) };

zones[zn( Z["Crystalsong Forest"] )].zones = { zn( Z["Dalaran"] ), zn( Z["Zul'Drak"] ), zn( Z["Dragonblight"] ), zn( Z["Icecrown"] ), zn( Z["The Storm Peaks"] ) };
zones[zn( Z["Dalaran"] )].zones = { zn( Z["Crystalsong Forest"] ), zn( Z["The Violet Hold"] ), zn( L["Portal"], 10 ), zn( L["Portal"], 11 ), zn( L["Portal"], 12 ), zn( L["Portal"], 13 ), zn( L["Portal"], 14 ), zn( L["Portal"], 15 ), zn( L["Portal"], 16 ), zn( L["Portal"], 17 ), zn( L["Portal"], 18 ), zn( L["Portal"], 19 ), zn( L["Portal"], 20 ), zn( L["Portal"], 21 ), zn( L["Portal"], 22 ), zn( L["Portal"], 23 ), zn( L["Portal"], 24 ), zn( L["Portal"], 25 ), zn( L["Portal"], 26 ), zn( L["Portal"], 27 ), zn( L["Portal"], 28 ), zn( L["Portal"], 29 ), zn( L["Portal"], 30 ), zn( L["Portal"], 31 ), zn( L["Portal"], 32 ), zn( L["Portal"], 33 ), zn( L["Portal"], 34 ), zn( L["Portal"], 35 ) };
zones[zn( Z["The Violet Hold"] )].zones = { zn( Z["Dalaran"] ) };

zones[zn( Z["The Storm Peaks"] )].zones = { zn( Z["Crystalsong Forest"] ), zn( Z["Ulduar"], 1 ) };
zones[zn( Z["Ulduar"], 1 )].zones = { zn( Z["The Storm Peaks"] ), zn( Z["Halls of Stone"] ), zn( Z["Halls of Lightning"] ), zn( Z["Ulduar"], 2 ) };
zones[zn( Z["Halls of Stone"] )].zones = { zn( Z["Ulduar"], 1 ) };
zones[zn( Z["Halls of Lightning"] )].zones = { zn( Z["Ulduar"], 1 ) };
zones[zn( Z["Ulduar"], 2 )].zones = { zn( Z["Ulduar"], 1 ) };

zones[zn( Z["Icecrown"] )].zones = { zn( Z["Crystalsong Forest"] ), zn( Z["Icecrown Citadel"] ) };
zones[zn( Z["Icecrown Citadel"] )].zones = { zn( Z["Icecrown"] ) };

zones[zn( Z["Wintergrasp"] )].zones = { zn( L["Vault of Archavon"] ) };
zones[zn( L["Vault of Archavon"] )].zones = { zn( Z["Wintergrasp"] ) };
